@@ -1,10 +1,10 @@
 from .Image import Image
-from .Meta import Meta, TrainingMeta, EvaluationMeta
+from .Meta import PredictMeta, TrainingMeta, EvaluationMeta
 from .Model import Model, EvaluationModel
 
 __all__ = [
     Image,
-    Meta,
+    PredictMeta,
     Model,
     EvaluationModel,
     TrainingMeta,
