@@ -1,8 +1,6 @@
-from pydantic import BaseModel, root_validator
+from pydantic import BaseModel
 from typing import Optional
 
-# from utils import check_file_exists
-
 
 class ModelMetaRequest(BaseModel):
     images_csv: str
