@@ -1,4 +1,4 @@
-from captur_ml_sdk.dtypes.generics import Image, Meta, Model
+from captur_ml_sdk.dtypes.generics import Image, PredictMeta, Model
 from captur_ml_sdk.utils import get_image_components
 from captur_ml_sdk.dtypes.exceptions import InvalidFilePathError
 from captur_ml_sdk.dtypes.interfaces.validators import (
@@ -35,6 +35,6 @@ class Data(BaseModel):
 
 
 class ModelPredictRequest(BaseModel):
-    meta: Optional[Meta] = None
+    meta: Optional[PredictMeta] = None
     models: List[Model]
     data: Data
